aboutsummaryrefslogtreecommitdiffstats
path: root/src/ginput
diff options
context:
space:
mode:
authorinmarket <andrewh@inmarket.com.au>2018-02-27 17:44:21 +1000
committerinmarket <andrewh@inmarket.com.au>2018-02-27 17:44:21 +1000
commitf265924396167729e8d9fb36a0383263f36c1270 (patch)
tree28843eb24b18999cf0217ecb0fe935f133901066 /src/ginput
parent14786e97b618b8bc2a0ff1c732d45288fe550e33 (diff)
downloaduGFX-f265924396167729e8d9fb36a0383263f36c1270.tar.gz
uGFX-f265924396167729e8d9fb36a0383263f36c1270.tar.bz2
uGFX-f265924396167729e8d9fb36a0383263f36c1270.zip
First set of V3 macro changes
Diffstat (limited to 'src/ginput')
-rw-r--r--src/ginput/ginput.h2
-rw-r--r--src/ginput/ginput_dial.h4
-rw-r--r--src/ginput/ginput_keyboard.c2
-rw-r--r--src/ginput/ginput_mouse.h8
-rw-r--r--src/ginput/ginput_options.h50
-rw-r--r--src/ginput/ginput_rules.h16
-rw-r--r--src/ginput/ginput_toggle.h4
7 files changed, 43 insertions, 43 deletions
diff --git a/src/ginput/ginput.h b/src/ginput/ginput.h
index 0aae5391..0a52e543 100644
--- a/src/ginput/ginput.h
+++ b/src/ginput/ginput.h
@@ -15,7 +15,7 @@
* @details GINPUT provides an easy and common interface to use different input devices
* such as touchscreens and mices.
*
- * @pre GFX_USE_GINPUT must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GINPUT must be set to GFXON in your gfxconf.h
*
* @{
*/
diff --git a/src/ginput/ginput_dial.h b/src/ginput/ginput_dial.h
index e0292cb6..77c1b05c 100644
--- a/src/ginput/ginput_dial.h
+++ b/src/ginput/ginput_dial.h
@@ -16,8 +16,8 @@
* @details A dial provides a powerful way to navigate through menus
* on a display.
*
- * @pre GFX_USE_GINPUT must be set to TRUE in your gfxconf.h
- * @pre GINPUT_NEED_DIAL must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GINPUT must be set to GFXON in your gfxconf.h
+ * @pre GINPUT_NEED_DIAL must be set to GFXON in your gfxconf.h
*
* @{
*/
diff --git a/src/ginput/ginput_keyboard.c b/src/ginput/ginput_keyboard.c
index 141bdd2b..68f05cea 100644
--- a/src/ginput/ginput_keyboard.c
+++ b/src/ginput/ginput_keyboard.c
@@ -17,7 +17,7 @@
#if GFX_USE_GINPUT && GINPUT_NEED_KEYBOARD
-#define MICROCODE_DEBUG FALSE
+#define MICROCODE_DEBUG GFXOFF
#if MICROCODE_DEBUG
#include <stdio.h>
diff --git a/src/ginput/ginput_mouse.h b/src/ginput/ginput_mouse.h
index 24005fe6..8d8b3b9a 100644
--- a/src/ginput/ginput_mouse.h
+++ b/src/ginput/ginput_mouse.h
@@ -15,8 +15,8 @@
*
* @details Both resistive and capacitive touchscreens are supported.
*
- * @pre GFX_USE_GINPUT must be set to TRUE in your gfxconf.h
- * @pre GINPUT_NEED_MOUSE must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GINPUT must be set to GFXON in your gfxconf.h
+ * @pre GINPUT_NEED_MOUSE must be set to GFXON in your gfxconf.h
*
* @{
*/
@@ -160,7 +160,7 @@ extern "C" {
* @param[in] sz The size in bytes of the data to retrieve.
*
* @note This routine is provided by the user application. It is only
- * called if GINPUT_TOUCH_USER_CALIBRATION_LOAD has been set to TRUE in the
+ * called if GINPUT_TOUCH_USER_CALIBRATION_LOAD has been set to GFXON in the
* users gfxconf.h file.
*/
bool_t LoadMouseCalibration(unsigned instance, void *data, size_t sz);
@@ -174,7 +174,7 @@ extern "C" {
* @param[in] sz The size in bytes of the data to retrieve.
*
* @note This routine is provided by the user application. It is only
- * called if GINPUT_TOUCH_USER_CALIBRATION_SAVE has been set to TRUE in the
+ * called if GINPUT_TOUCH_USER_CALIBRATION_SAVE has been set to GFXON in the
* users gfxconf.h file.
*/
bool_t SaveMouseCalibration(unsigned instance, const void *data, size_t sz);
diff --git a/src/ginput/ginput_options.h b/src/ginput/ginput_options.h
index 9fba51f9..f02a5a09 100644
--- a/src/ginput/ginput_options.h
+++ b/src/ginput/ginput_options.h
@@ -22,43 +22,43 @@
*/
/**
* @brief Should mouse/touch functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Also add a mouse/touch hardware driver to your makefile.
* Eg.
* include $(GFXLIB)/drivers/ginput/touch/MCU/driver.mk
*/
#ifndef GINPUT_NEED_MOUSE
- #define GINPUT_NEED_MOUSE FALSE
+ #define GINPUT_NEED_MOUSE GFXOFF
#endif
/**
* @brief Should keyboard functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Also add a keyboard hardware driver to your makefile.
* Eg.
* include $(GFXLIB)/drivers/ginput/keyboard/XXXX/driver.mk
*/
#ifndef GINPUT_NEED_KEYBOARD
- #define GINPUT_NEED_KEYBOARD FALSE
+ #define GINPUT_NEED_KEYBOARD GFXOFF
#endif
/**
* @brief Should hardware toggle/switch/button functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Also add a toggle hardware driver to your makefile.
* Eg.
* include $(GFXLIB)/drivers/ginput/toggle/Pal/driver.mk
*/
#ifndef GINPUT_NEED_TOGGLE
- #define GINPUT_NEED_TOGGLE FALSE
+ #define GINPUT_NEED_TOGGLE GFXOFF
#endif
/**
* @brief Should analog dial functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Also add a dial hardware driver to your makefile.
* Eg.
* include $(GFXLIB)/drivers/ginput/dial/analog/driver.mk
*/
#ifndef GINPUT_NEED_DIAL
- #define GINPUT_NEED_DIAL FALSE
+ #define GINPUT_NEED_DIAL GFXOFF
#endif
/**
* @}
@@ -74,16 +74,16 @@
*/
/**
* @brief Start touch devices without loading or running calibration.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note This is used if you want to manually control the initial calibration
* process. In practice this is only useful for a touch driver test program.
*/
#ifndef GINPUT_TOUCH_STARTRAW
- #define GINPUT_TOUCH_STARTRAW FALSE
+ #define GINPUT_TOUCH_STARTRAW GFXOFF
#endif
/**
* @brief Turn off the touch calibration GUI.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Turning off the calibration GUI just turns off the manual calibration
* process. Readings may still be calibrated if calibration data
* can be loaded.
@@ -91,28 +91,28 @@
* using this option can save a lot of space.
*/
#ifndef GINPUT_TOUCH_NOCALIBRATE_GUI
- #define GINPUT_TOUCH_NOCALIBRATE_GUI FALSE
+ #define GINPUT_TOUCH_NOCALIBRATE_GUI GFXOFF
#endif
/**
* @brief Turn off all touch calibration support.
- * @details Defaults to FALSE
- * @note With this set to TRUE touch readings will not be calibrated.
+ * @details Defaults to GFXOFF
+ * @note With this set to GFXON touch readings will not be calibrated.
* @note This automatically turns off the calibration GUI too!
* @note Calibration requires a lot of code. If your device doesn't require it
* using this option can save a lot of space.
*/
#ifndef GINPUT_TOUCH_NOCALIBRATE
- #define GINPUT_TOUCH_NOCALIBRATE FALSE
+ #define GINPUT_TOUCH_NOCALIBRATE GFXOFF
#endif
/**
* @brief Turn off all touch support.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note This automatically turns off all calibration and the calibration GUI too!
* @note Touch device handling requires a lot of code. If your device doesn't require it
* using this option can save a lot of space.
*/
#ifndef GINPUT_TOUCH_NOTOUCH
- #define GINPUT_TOUCH_NOTOUCH FALSE
+ #define GINPUT_TOUCH_NOTOUCH GFXOFF
#endif
/**
* @brief Milliseconds between mouse polls.
@@ -143,19 +143,19 @@
#endif
/**
* @brief There is a user supplied routine to load mouse calibration data
- * @details Defaults to FALSE
- * @note If TRUE the user must supply the @p LoadMouseCalibration() routine.
+ * @details Defaults to GFXOFF
+ * @note If GFXON the user must supply the @p LoadMouseCalibration() routine.
*/
#ifndef GINPUT_TOUCH_USER_CALIBRATION_LOAD
- #define GINPUT_TOUCH_USER_CALIBRATION_LOAD FALSE
+ #define GINPUT_TOUCH_USER_CALIBRATION_LOAD GFXOFF
#endif
/**
* @brief There is a user supplied routine to save mouse calibration data
- * @details Defaults to FALSE
- * @note If TRUE the user must supply the @p SaveMouseCalibration() routine.
+ * @details Defaults to GFXOFF
+ * @note If GFXON the user must supply the @p SaveMouseCalibration() routine.
*/
#ifndef GINPUT_TOUCH_USER_CALIBRATION_SAVE
- #define GINPUT_TOUCH_USER_CALIBRATION_SAVE FALSE
+ #define GINPUT_TOUCH_USER_CALIBRATION_SAVE GFXOFF
#endif
#if defined(__DOXYGEN__)
/**
@@ -198,7 +198,7 @@
* @note Turning off the layout engine just saves code if it is not needed.
*/
#ifndef GKEYBOARD_LAYOUT_OFF
- #define GKEYBOARD_LAYOUT_OFF FALSE
+ #define GKEYBOARD_LAYOUT_OFF GFXOFF
#endif
/**
* @brief Various Keyboard Layouts that can be included.
@@ -212,7 +212,7 @@
* @{
*/
#ifndef GKEYBOARD_LAYOUT_SCANCODE2_US
- #define GKEYBOARD_LAYOUT_SCANCODE2_US FALSE // US Keyboard using the ScanCode 2 set.
+ #define GKEYBOARD_LAYOUT_SCANCODE2_US GFXOFF // US Keyboard using the ScanCode 2 set.
#endif
/** @} */
/** @} */
diff --git a/src/ginput/ginput_toggle.h b/src/ginput/ginput_toggle.h
index ad896bf6..7d028301 100644
--- a/src/ginput/ginput_toggle.h
+++ b/src/ginput/ginput_toggle.h
@@ -16,8 +16,8 @@
* @details GINPUT allows it to interface toggle buttons easily to your
* application.
*
- * @pre GFX_USE_GINPUT must be set to TRUE in your gfxconf.h
- * @pre GINPUT_NEED_TOGGLE must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GINPUT must be set to GFXON in your gfxconf.h
+ * @pre GINPUT_NEED_TOGGLE must be set to GFXON in your gfxconf.h
*
* @{
*/
diff --git a/src/ginput/ginput_rules.h b/src/ginput/ginput_rules.h
index 5825e2f0..d78f0c4c 100644
--- a/src/ginput/ginput_rules.h
+++ b/src/ginput/ginput_rules.h
@@ -20,35 +20,35 @@
#if !GFX_USE_GEVENT
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GINPUT: GFX_USE_GEVENT is required if GFX_USE_GINPUT is TRUE. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GINPUT: GFX_USE_GEVENT is required if GFX_USE_GINPUT is TRUE. It has been turned on for you.")
+ COMPILER_WARNING("GINPUT: GFX_USE_GEVENT is required if GFX_USE_GINPUT is GFXON. It has been turned on for you.")
#endif
#endif
#undef GFX_USE_GEVENT
- #define GFX_USE_GEVENT TRUE
+ #define GFX_USE_GEVENT GFXON
#endif
#if !GFX_USE_GTIMER
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GINPUT: GFX_USE_GTIMER is required if GFX_USE_GINPUT is TRUE. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GINPUT: GFX_USE_GTIMER is required if GFX_USE_GINPUT is TRUE. It has been turned on for you.")
+ COMPILER_WARNING("GINPUT: GFX_USE_GTIMER is required if GFX_USE_GINPUT is GFXON. It has been turned on for you.")
#endif
#endif
#undef GFX_USE_GTIMER
- #define GFX_USE_GTIMER TRUE
+ #define GFX_USE_GTIMER GFXON
#endif
#if GINPUT_NEED_MOUSE
#if GINPUT_TOUCH_NOTOUCH
// No warning needed for this
#undef GINPUT_TOUCH_NOCALIBRATE
- #define GINPUT_TOUCH_NOCALIBRATE TRUE
+ #define GINPUT_TOUCH_NOCALIBRATE GFXON
#endif
#if GINPUT_TOUCH_NOCALIBRATE
// No warning needed for this
#undef GINPUT_TOUCH_NOCALIBRATE_GUI
- #define GINPUT_TOUCH_NOCALIBRATE_GUI TRUE
+ #define GINPUT_TOUCH_NOCALIBRATE_GUI GFXON
#endif
#if !GINPUT_TOUCH_NOTOUCH && GINPUT_MOUSE_CLICK_TIME > GINPUT_TOUCH_CXTCLICK_TIME
#error "GINPUT MOUSE: The GINPUT_MOUSE_CLICK_TIME must be <= GINPUT_TOUCH_CXTCLICK_TIME"
@@ -20,35 +20,35 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GINPUT: GFX_USE_GEVENT is required if GFX_USE_GINPUT is TRUE. It has been turned on for you."
+ #warning "GINPUT: GFX_USE_GEVENT is required if GFX_USE_GINPUT is GFXON. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
@@ -20,35 +20,35 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GINPUT: GFX_USE_GTIMER is required if GFX_USE_GINPUT is TRUE. It has been turned on for you."
+ #warning "GINPUT: GFX_USE_GTIMER is required if GFX_USE_GINPUT is GFXON. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO